##  Step 1: Create an Import Template
Using the export functionality, create a template with columns for each needed fact sheet attribute. This template, with properly formatted column titles, ensures a smooth and accurate data import process.
To learn how to create an import template, see [Creating a Template for Import](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759eb787a441014923281e9be89d344__creating_the_template_for_import).
